==> cscec5b-wzxt-impl-3.0.0-20201105.101119-29-sources.jar: com/ejianc/business/wzxt/bean/WeighReportEntity.java <==
package com.ejianc.business.wzxt.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 智能称重台账实体
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_weigh_report")
public class WeighReportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pk_weigh_bill")
    private String pkWeighBill; // 磅单主键
    @TableField(value="weigh_code")
    private String weighCode; // 磅单编号
    @TableField(value="plate_number")
    private String plateNumber; // 车牌号
    @TableField(value="pk_supplier")
    private Long pkSupplier; // 供应商主键
    @TableField(value="forwarding_unit")
    private String forwardingUnit; // 发货单位、供应商
    @TableField(value="pk_project")
    private Long pkProject; // 项目主键
    @TableField(value="consignee_unit")
    private String consigneeUnit; // 收货单位、收货项目
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="gross_weight")
    private java.math.BigDecimal grossWeight; // 毛重
    @TableField(value="tare_weight")
    private java.math.BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private java.math.BigDecimal netWeight; // 净重
    @TableField(value="weight_unit")
    private String weightUnit; // 重量单位
    @TableField(value="gross_time")
    private String grossTime; // 毛重时间
    @TableField(value="tare_time")
    private String tareTime; // 皮重时间
    @TableField(value="remark")
    private String remark; //
    @TableField(value="lp_id")
    private String lpId; // 轻量化平台组合ID  发货单ID&发货单子表ID
    @TableField(value="third_weigh_id")
    private String thirdWeighId; // 来源称重系统称重结果ID
    @TableField(value="pk_delivery")
    private Long pkDelivery; // 发货单主键
    @TableField(value="pk_delivery_b")
    private Long pkDeliveryB; // 发货单子表主键
    @TableField(value="pk_purchase_b")
    private Long pkPurchaseB; // 订单子表主键
    @TableField(value="pk_weigh_apply")
    private String pkWeighApply; // 过磅申请主键
    @TableField(value="pk_material")
    private Long pkMaterial; // 物料主键
    @TableField(value="pk_matclass")
    private Long pkMatclass; // 物料类别
    @TableField(value="matclass_name")
    private String matclassName; // 物料类别名称
    @TableField(value="pk_check")
    private Long pkCheck; // 验收单主键
    @TableField(value="check_status")
    private Integer checkStatus; // 验收状态  0-未验收  1- 已验收
    @TableField(value="source")
    private String source; // 数据来源
    @TableField(value="pk_contract_purchase")
    private String pkContractPurchase; // 合同主键
    @TableField(value="contract_purchase_name")
    private String contractPurchaseName; // 合同名称
    @TableField(value="contract_purchase_code")
    private String contractPurchaseCode; // 合同编号
    @TableField(value="plan_body")
    private String planBody; // 工程部位
    @TableField(value="result_num")
    private java.math.BigDecimal resultNum; // 折算后数量
    @TableField(value="unit_ratio")
    private java.math.BigDecimal unitRatio; // 单位转换系数
    @TableField(value="order_num")
    private java.math.BigDecimal orderNum; // 订单数量
    @TableField(value="delivery_num")
    private java.math.BigDecimal deliveryNum; // 供方数量
    @TableField(value="order_code")
    private String orderCode; // 订单编号
    @TableField(value="check_code")
    private String checkCode; // 验收单号
    @TableField(value="delivery_code")
    private String deliveryCode; // 发货编号
    @TableField(value="material_code")
    private String materialCode; // 物料名称
    @TableField(exist = false)
    private Long projOrgId;


    /**
     * 磅单主键
     */
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    /**
     * 磅单主键
     */
    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    /**
     * 磅单编号
     */
    public String getWeighCode() {
        return weighCode;
    }

    /**
     * 磅单编号
     */
    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    /**
     * 车牌号
     */
    public String getPlateNumber() {
        return plateNumber;
    }

    /**
     * 车牌号
     */
    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    /**
     * 供应商主键
     */
    public Long getPkSupplier() {
        return pkSupplier;
    }

    /**
     * 供应商主键
     */
    public void setPkSupplier(Long pkSupplier) {
        this.pkSupplier = pkSupplier;
    }
    /**
     * 发货单位、供应商
     */
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    /**
     * 发货单位、供应商
     */
    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    /**
     * 项目主键
     */
    public Long getPkProject() {
        return pkProject;
    }

    /**
     * 项目主键
     */
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    /**
     * 收货单位、收货项目
     */
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    /**
     * 收货单位、收货项目
     */
    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getMaterialSpec() {
        return materialSpec;
    }

    /**
     * 规格型号
     */
    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    /**
     * 毛重
     */
    public java.math.BigDecimal getGrossWeight() {
        return grossWeight;
    }

    /**
     * 毛重
     */
    public void setGrossWeight(java.math.BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    /**
     * 皮重
     */
    public java.math.BigDecimal getTareWeight() {
        return tareWeight;
    }

    /**
     * 皮重
     */
    public void setTareWeight(java.math.BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    /**
     * 净重
     */
    public java.math.BigDecimal getNetWeight() {
        return netWeight;
    }

    /**
     * 净重
     */
    public void setNetWeight(java.math.BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    /**
     * 重量单位
     */
    public String getWeightUnit() {
        return weightUnit;
    }

    /**
     * 重量单位
     */
    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    /**
     * 毛重时间
     */
    public String getGrossTime() {
        return grossTime;
    }

    /**
     * 毛重时间
     */
    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    /**
     * 皮重时间
     */
    public String getTareTime() {
        return tareTime;
    }

    /**
     * 皮重时间
     */
    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    /**
     *
     */
    public String getRemark() {
        return remark;
    }

    /**
     *
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public String getLpId() {
        return lpId;
    }

    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public void setLpId(String lpId) {
        this.lpId = lpId;
    }
    /**
     * 来源称重系统称重结果ID
     */
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    /**
     * 来源称重系统称重结果ID
     */
    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    /**
     * 发货单主键
     */
    public Long getPkDelivery() {
        return pkDelivery;
    }

    /**
     * 发货单主键
     */
    public void setPkDelivery(Long pkDelivery) {
        this.pkDelivery = pkDelivery;
    }
    /**
     * 发货单子表主键
     */
    public Long getPkDeliveryB() {
        return pkDeliveryB;
    }

    /**
     * 发货单子表主键
     */
    public void setPkDeliveryB(Long pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }
    /**
     * 订单子表主键
     */
    public Long getPkPurchaseB() {
        return pkPurchaseB;
    }

    /**
     * 订单子表主键
     */
    public void setPkPurchaseB(Long pkPurchaseB) {
        this.pkPurchaseB = pkPurchaseB;
    }
    /**
     * 过磅申请主键
     */
    public String getPkWeighApply() {
        return pkWeighApply;
    }

    /**
     * 过磅申请主键
     */
    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }
    /**
     * 物料主键
     */
    public Long getPkMaterial() {
        return pkMaterial;
    }

    /**
     * 物料主键
     */
    public void setPkMaterial(Long pkMaterial) {
        this.pkMaterial = pkMaterial;
    }
    /**
     * 物料类别
     */
    public Long getPkMatclass() {
        return pkMatclass;
    }

    /**
     * 物料类别
     */
    public void setPkMatclass(Long pkMatclass) {
        this.pkMatclass = pkMatclass;
    }
    /**
     * 物料类别名称
     */
    public String getMatclassName() {
        return matclassName;
    }

    /**
     * 物料类别名称
     */
    public void setMatclassName(String matclassName) {
        this.matclassName = matclassName;
    }
    /**
     * 验收单主键
     */
    public Long getPkCheck() {
        return pkCheck;
    }

    /**
     * 验收单主键
     */
    public void setPkCheck(Long pkCheck) {
        this.pkCheck = pkCheck;
    }
    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public Integer getCheckStatus() {
        return checkStatus;
    }

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }
    /**
     * 数据来源
     */
    public String getSource() {
        return source;
    }

    /**
     * 数据来源
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 合同主键
     */
    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    /**
     * 合同主键
     */
    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }
    /**
     * 合同名称
     */
    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    /**
     * 合同名称
     */
    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }
    /**
     * 合同编号
     */
    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    /**
     * 合同编号
     */
    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }
    /**
     * 工程部位
     */
    public String getPlanBody() {
        return planBody;
    }

    /**
     * 工程部位
     */
    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }
    /**
     * 折算后数量
     */
    public java.math.BigDecimal getResultNum() {
        return resultNum;
    }

    /**
     * 折算后数量
     */
    public void setResultNum(java.math.BigDecimal resultNum) {
        this.resultNum = resultNum;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNum() {
        return orderNum;
    }

    /**
     * 订单数量
     */
    public void setOrderNum(java.math.BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    /**
     * 供方数量
     */
    public java.math.BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    /**
     * 供方数量
     */
    public void setDeliveryNum(java.math.BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    /**
     * 订单编号
     */
    public String getOrderCode() {
        return orderCode;
    }

    /**
     * 订单编号
     */
    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }
    /**
     * 验收单号
     */
    public String getCheckCode() {
        return checkCode;
    }

    /**
     * 验收单号
     */
    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    /**
     * 发货编号
     */
    public String getDeliveryCode() {
        return deliveryCode;
    }

    /**
     * 发货编号
     */
    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }
    /**
     * 物料名称
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料名称
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getProjOrgId() {
        return projOrgId;
    }

    public void setProjOrgId(Long projOrgId) {
        this.projOrgId = projOrgId;
    }
}

==> cscec5b-wzxt-impl-3.0.0-20201209.111519-113-sources.jar: com/ejianc/business/wzxt/bean/WeighReportEntity.java <==
package com.ejianc.business.wzxt.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 智能称重台账实体
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_weigh_report")
public class WeighReportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pk_weigh_bill")
    private String pkWeighBill; // 磅单主键
    @TableField(value="weigh_code")
    private String weighCode; // 磅单编号
    @TableField(value="plate_number")
    private String plateNumber; // 车牌号
    @TableField(value="pk_supplier")
    private Long pkSupplier; // 供应商主键
    @TableField(value="forwarding_unit")
    private String forwardingUnit; // 发货单位、供应商
    @TableField(value="pk_project")
    private Long pkProject; // 项目主键
    @TableField(value="consignee_unit")
    private String consigneeUnit; // 收货单位、收货项目
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="gross_weight")
    private java.math.BigDecimal grossWeight; // 毛重
    @TableField(value="tare_weight")
    private java.math.BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private java.math.BigDecimal netWeight; // 净重
    @TableField(value="weight_unit")
    private String weightUnit; // 重量单位
    @TableField(value="gross_time")
    private String grossTime; // 毛重时间
    @TableField(value="tare_time")
    private String tareTime; // 皮重时间
    @TableField(value="remark")
    private String remark; //
    @TableField(value="lp_id")
    private String lpId; // 轻量化平台组合ID  发货单ID&发货单子表ID
    @TableField(value="third_weigh_id")
    private String thirdWeighId; // 来源称重系统称重结果ID
    @TableField(value="pk_delivery")
    private Long pkDelivery; // 发货单主键
    @TableField(value="pk_delivery_b")
    private Long pkDeliveryB; // 发货单子表主键
    @TableField(value="pk_purchase_b")
    private Long pkPurchaseB; // 订单子表主键
    @TableField(value="pk_weigh_apply")
    private String pkWeighApply; // 过磅申请主键
    @TableField(value="pk_material")
    private Long pkMaterial; // 物料主键
    @TableField(value="pk_matclass")
    private Long pkMatclass; // 物料类别
    @TableField(value="matclass_name")
    private String matclassName; // 物料类别名称
    @TableField(value="pk_check")
    private Long pkCheck; // 验收单主键
    @TableField(value="check_status")
    private Integer checkStatus; // 验收状态  0-未验收  1- 已验收
    @TableField(value="source")
    private String source; // 数据来源
    @TableField(value="pk_contract_purchase")
    private String pkContractPurchase; // 合同主键
    @TableField(value="contract_purchase_name")
    private String contractPurchaseName; // 合同名称
    @TableField(value="contract_purchase_code")
    private String contractPurchaseCode; // 合同编号
    @TableField(value="plan_body")
    private String planBody; // 工程部位
    @TableField(value="result_num")
    private java.math.BigDecimal resultNum; // 折算后数量
    @TableField(value="unit_ratio")
    private java.math.BigDecimal unitRatio; // 单位转换系数
    @TableField(value="order_num")
    private java.math.BigDecimal orderNum; // 订单数量
    @TableField(value="delivery_num")
    private java.math.BigDecimal deliveryNum; // 供方数量
    @TableField(value="order_code")
    private String orderCode; // 订单编号
    @TableField(value="check_code")
    private String checkCode; // 验收单号
    @TableField(value="delivery_code")
    private String deliveryCode; // 发货编号
    @TableField(value="material_code")
    private String materialCode; // 物料名称
    @TableField(value="proj_org_id")
    private Long projOrgId;// 项目部组织主键


    /**
     * 磅单主键
     */
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    /**
     * 磅单主键
     */
    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    /**
     * 磅单编号
     */
    public String getWeighCode() {
        return weighCode;
    }

    /**
     * 磅单编号
     */
    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    /**
     * 车牌号
     */
    public String getPlateNumber() {
        return plateNumber;
    }

    /**
     * 车牌号
     */
    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    /**
     * 供应商主键
     */
    public Long getPkSupplier() {
        return pkSupplier;
    }

    /**
     * 供应商主键
     */
    public void setPkSupplier(Long pkSupplier) {
        this.pkSupplier = pkSupplier;
    }
    /**
     * 发货单位、供应商
     */
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    /**
     * 发货单位、供应商
     */
    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    /**
     * 项目主键
     */
    public Long getPkProject() {
        return pkProject;
    }

    /**
     * 项目主键
     */
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    /**
     * 收货单位、收货项目
     */
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    /**
     * 收货单位、收货项目
     */
    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getMaterialSpec() {
        return materialSpec;
    }

    /**
     * 规格型号
     */
    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    /**
     * 毛重
     */
    public java.math.BigDecimal getGrossWeight() {
        return grossWeight;
    }

    /**
     * 毛重
     */
    public void setGrossWeight(java.math.BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    /**
     * 皮重
     */
    public java.math.BigDecimal getTareWeight() {
        return tareWeight;
    }

    /**
     * 皮重
     */
    public void setTareWeight(java.math.BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    /**
     * 净重
     */
    public java.math.BigDecimal getNetWeight() {
        return netWeight;
    }

    /**
     * 净重
     */
    public void setNetWeight(java.math.BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    /**
     * 重量单位
     */
    public String getWeightUnit() {
        return weightUnit;
    }

    /**
     * 重量单位
     */
    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    /**
     * 毛重时间
     */
    public String getGrossTime() {
        return grossTime;
    }

    /**
     * 毛重时间
     */
    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    /**
     * 皮重时间
     */
    public String getTareTime() {
        return tareTime;
    }

    /**
     * 皮重时间
     */
    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    /**
     *
     */
    public String getRemark() {
        return remark;
    }

    /**
     *
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public String getLpId() {
        return lpId;
    }

    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public void setLpId(String lpId) {
        this.lpId = lpId;
    }
    /**
     * 来源称重系统称重结果ID
     */
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    /**
     * 来源称重系统称重结果ID
     */
    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    /**
     * 发货单主键
     */
    public Long getPkDelivery() {
        return pkDelivery;
    }

    /**
     * 发货单主键
     */
    public void setPkDelivery(Long pkDelivery) {
        this.pkDelivery = pkDelivery;
    }
    /**
     * 发货单子表主键
     */
    public Long getPkDeliveryB() {
        return pkDeliveryB;
    }

    /**
     * 发货单子表主键
     */
    public void setPkDeliveryB(Long pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }
    /**
     * 订单子表主键
     */
    public Long getPkPurchaseB() {
        return pkPurchaseB;
    }

    /**
     * 订单子表主键
     */
    public void setPkPurchaseB(Long pkPurchaseB) {
        this.pkPurchaseB = pkPurchaseB;
    }
    /**
     * 过磅申请主键
     */
    public String getPkWeighApply() {
        return pkWeighApply;
    }

    /**
     * 过磅申请主键
     */
    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }
    /**
     * 物料主键
     */
    public Long getPkMaterial() {
        return pkMaterial;
    }

    /**
     * 物料主键
     */
    public void setPkMaterial(Long pkMaterial) {
        this.pkMaterial = pkMaterial;
    }
    /**
     * 物料类别
     */
    public Long getPkMatclass() {
        return pkMatclass;
    }

    /**
     * 物料类别
     */
    public void setPkMatclass(Long pkMatclass) {
        this.pkMatclass = pkMatclass;
    }
    /**
     * 物料类别名称
     */
    public String getMatclassName() {
        return matclassName;
    }

    /**
     * 物料类别名称
     */
    public void setMatclassName(String matclassName) {
        this.matclassName = matclassName;
    }
    /**
     * 验收单主键
     */
    public Long getPkCheck() {
        return pkCheck;
    }

    /**
     * 验收单主键
     */
    public void setPkCheck(Long pkCheck) {
        this.pkCheck = pkCheck;
    }
    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public Integer getCheckStatus() {
        return checkStatus;
    }

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }
    /**
     * 数据来源
     */
    public String getSource() {
        return source;
    }

    /**
     * 数据来源
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 合同主键
     */
    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    /**
     * 合同主键
     */
    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }
    /**
     * 合同名称
     */
    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    /**
     * 合同名称
     */
    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }
    /**
     * 合同编号
     */
    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    /**
     * 合同编号
     */
    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }
    /**
     * 工程部位
     */
    public String getPlanBody() {
        return planBody;
    }

    /**
     * 工程部位
     */
    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }
    /**
     * 折算后数量
     */
    public java.math.BigDecimal getResultNum() {
        return resultNum;
    }

    /**
     * 折算后数量
     */
    public void setResultNum(java.math.BigDecimal resultNum) {
        this.resultNum = resultNum;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNum() {
        return orderNum;
    }

    /**
     * 订单数量
     */
    public void setOrderNum(java.math.BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    /**
     * 供方数量
     */
    public java.math.BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    /**
     * 供方数量
     */
    public void setDeliveryNum(java.math.BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    /**
     * 订单编号
     */
    public String getOrderCode() {
        return orderCode;
    }

    /**
     * 订单编号
     */
    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }
    /**
     * 验收单号
     */
    public String getCheckCode() {
        return checkCode;
    }

    /**
     * 验收单号
     */
    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    /**
     * 发货编号
     */
    public String getDeliveryCode() {
        return deliveryCode;
    }

    /**
     * 发货编号
     */
    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }
    /**
     * 物料名称
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料名称
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getProjOrgId() {
        return projOrgId;
    }

    public void setProjOrgId(Long projOrgId) {
        this.projOrgId = projOrgId;
    }
}
